package com.moyosoft.samples.excel.gui;

import javax.swing.*;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;

public class SourceCodeDialog extends JDialog
{
   protected JButton mButtonClose = new JButton("Close");
   protected JTextPane mSourceCodeText = new JTextPane();

   public SourceCodeDialog(Frame pParent, URL sourceCodeUrl)
   {
      super(pParent, "", true);
      setTitle("Source code");
      init(sourceCodeUrl);
   }

   public SourceCodeDialog(Dialog pParent, URL sourceCodeUrl)
   {
     super(pParent, "", true);
     setTitle("Source code");
     init(sourceCodeUrl);
   }

   private void init(URL sourceCodeUrl)
   {
      FlowLayout flowLayout = new FlowLayout();
      flowLayout.setAlignment(FlowLayout.RIGHT);
      JPanel buttonsPanel = new JPanel(flowLayout);
      buttonsPanel.add(mButtonClose);

      JPanel contentPanel = new JPanel(new BorderLayout());

      mSourceCodeText.setEditable(false);
      
      try
      {
          mSourceCodeText.setPage(sourceCodeUrl);
      }
      catch(IOException ex)
      {
      }
      
      mSourceCodeText.setCaretPosition(0);

      JScrollPane scrollPane = new JScrollPane(mSourceCodeText);
      contentPanel.add(scrollPane, BorderLayout.CENTER);
      contentPanel.setBorder(BorderFactory.createEmptyBorder(0,0,0,0));

      JPanel separatorPanel = new JPanel(new BorderLayout());
	  separatorPanel.add(BorderLayout.SOUTH, buttonsPanel);
      
      JPanel mainPanel = new JPanel(new BorderLayout());
      mainPanel.add(BorderLayout.CENTER, contentPanel);
      mainPanel.add(BorderLayout.SOUTH, separatorPanel);

      this.getContentPane().setLayout(new BorderLayout());
      this.getContentPane().add(BorderLayout.CENTER, mainPanel);

      resizeDialog();
      centerScreen();

      mButtonClose.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e)
            {
               dispose();
            }
         });
   }

   // centers the dialog within the screen
   protected void centerScreen()
   {
       Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
       Dimension windowSize = getSize();
       windowSize.height = Math.min(windowSize.height + 20, screenSize.height);
       windowSize.width = Math.min(windowSize.width, screenSize.width);
       setLocation((screenSize.width - windowSize.width) / 2,
               (screenSize.height - windowSize.height) / 2);
       
       requestFocus();
   }

   protected void resizeDialog()
   {
      setSize(650, 700);
   }

   public static void open(Frame pParent, URL sourceCodeUrl)
   {
      SourceCodeDialog dlg = new SourceCodeDialog(pParent, sourceCodeUrl);
      dlg.setVisible(true);
   }
   
   public static void open(Dialog pParent, URL sourceCodeUrl)
   {
       SourceCodeDialog dlg = new SourceCodeDialog(pParent, sourceCodeUrl);
      dlg.setVisible(true);
   }
}
